@@ -48,11 +48,11 @@ class Gateway():
         if discover:
             self.discover()
 
-        self.readThread = threading.Thread(target=self.readFromPort)
-        self.readThread.start()
+        #self.readThread = threading.Thread(target=self.readFromPort)
+        #self.readThread.start()
 
-        self.writeThread = threading.Thread(target=self.writePort)
-        self.writeThread.start()
+        #self.writeThread = threading.Thread(target=self.writePort)
+        #self.writeThread.start()
     
     def configserial(self):
         """
@@ -271,7 +271,7 @@ class Gateway():
         self.list_devices() 
        
     def addDevice(self, id, device):
-        self.devices = self.devices | {id:device}
+        self.devices = self.devices.update({id:device})
 
     def deleteDevice(self, id):
         if self.is_id_registered(id):
@@ -381,21 +381,28 @@ class Gateway():
 
         commandStart.execute(self)
         commandResult.execute(self)
-        while commandResult.scanState != ScanState.END_SUCCESS and commandResult.scanState != ScanState.END_FAILED:
+        while commandResult.scanState == ScanState.RUN or commandResult.scanState == ScanState.VERIFY:
             commandResult.execute(self)
-            #wait(1)
+            time.sleep(1)
         if commandResult.scanState == ScanState.END_SUCCESS:
             if commandResult.noNewDevices > 0:
                 return commandResult.foundIds
 
-        return []
+        return {}
 
     def saveActorDevices(self, ids):
         if len(ids) > 0:
             for id in ids:
                 commandSave = CommeoDeviceSave(id)
                 commandSave.execute(self)
-                self.devices = self.devices | dict(([id, ActorDevice(self, id , True)]))
+                dev = ActorDevice(self, id , True)
+                self.addDevice(id, dev)
+                dev.saveDevice()
+
+    def deleteActorDevice(self, id):
+        if self.is_id_registered(id):
+            dev:ActorDevice = self.devices[id]
+            dev.deleteDevice()
 
 ## Group
 
